"""Framework integration helpers for ``oidc_jwt_verifier``.

Submodules:
    fastapi: FastAPI dependency factories and error translation helpers.
    starlette: Starlette middleware and request helpers.
"""

__all__: list[str] = []
